package com.example.refactor.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * 快照感知注解
 * 标记需要快照处理的方法
 */
@Target({ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
public @interface SnapshotAware {
    
    /**
     * 操作类型
     */
    OperationType operation() default OperationType.QUERY;
    
    /**
     * 是否在操作前创建快照
     */
    boolean createSnapshotBefore() default false;
    
    /**
     * 快照创建原因
     */
    String snapshotReason() default "";
    
    enum OperationType {
        /**
         * 查询操作
         */
        QUERY,
        
        /**
         * 更新操作
         */
        UPDATE,
        
        /**
         * 删除操作
         */
        DELETE,
        
        /**
         * 创建操作
         */
        CREATE
    }
} 