package com.example.refactor.demo;

import com.example.refactor.entity.User;
import com.example.refactor.service.UserManagementService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;

/**
 * 快照功能演示
 * 展示AOP注解方案的效果
 */
@Component
public class SnapshotDemo implements CommandLineRunner {
    
    @Autowired
    private UserManagementService userManagementService;
    
    @Override
    public void run(String... args) throws Exception {
        System.out.println("=== 快照功能演示 ===");
        
        // 1. 创建用户
        System.out.println("\n1. 创建用户");
        User user = userManagementService.createUser("张三", "zhangsan@example.com", "13800138000");
        System.out.println("创建用户: " + user.getName() + " (" + user.getEmail() + ")");
        
        // 2. 查询用户（自动应用快照逻辑）
        System.out.println("\n2. 查询用户");
        User queriedUser = userManagementService.getUserById(user.getId());
        System.out.println("查询用户: " + queriedUser.getName() + " (" + queriedUser.getEmail() + ")");
        System.out.println("快照ID: " + (queriedUser.getSnapshotId() != null ? queriedUser.getSnapshotId() : "无"));
        
        // 3. 更新用户（自动创建快照）
        System.out.println("\n3. 更新用户");
        User updatedUser = userManagementService.updateUser(
                user.getId(), 
                "张三（已更新）", 
                "zhangsan.updated@example.com", 
                "13800138001"
        );
        System.out.println("更新用户: " + updatedUser.getName() + " (" + updatedUser.getEmail() + ")");
        
        // 4. 再次查询用户
        System.out.println("\n4. 再次查询用户");
        User queriedUser2 = userManagementService.getUserById(user.getId());
        System.out.println("查询用户: " + queriedUser2.getName() + " (" + queriedUser2.getEmail() + ")");
        System.out.println("快照ID: " + (queriedUser2.getSnapshotId() != null ? queriedUser2.getSnapshotId() : "无"));
        
        // 5. 删除用户（自动创建快照）
        System.out.println("\n5. 删除用户");
        userManagementService.deleteUser(user.getId());
        System.out.println("用户已删除");
        
        // 6. 查询删除后的用户
        System.out.println("\n6. 查询删除后的用户");
        User deletedUser = userManagementService.getUserById(user.getId());
        System.out.println("用户状态: " + deletedUser.getStatus());
        
        System.out.println("\n=== 演示完成 ===");
        System.out.println("注意：所有操作都通过AOP自动应用了快照逻辑，业务代码保持原样！");
    }
} 