package com.example.refactor.service;

import com.example.refactor.entity.User;
import com.example.refactor.repository.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * HR服务 - 负责员工职位、薪资、部门等信息管理
 * 通过方法签名模式自动支持快照功能
 */
@Service
public class HRService {
    
    @Autowired
    private UserRepository userRepository;
    
    public User updateEmployeeInfo(Long userId, String department, String position, Double salary) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null) {
            user.setDepartment(department);
            user.setPosition(position);
            user.setSalary(salary);
            user.setUpdateTime(new Date());
            return userRepository.save(user);
        }
        return null;
    }
    
    public List<User> getEmployeesByDepartment(String department) {
        return userRepository.findByDepartment(department);
    }
    
    public User promoteEmployee(Long userId, String newPosition, Double newSalary) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null) {
            user.setPosition(newPosition);
            user.setSalary(newSalary);
            user.setUpdateTime(new Date());
            return userRepository.save(user);
        }
        return null;
    }
    
    public User transferEmployee(Long userId, String newDepartment) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null) {
            user.setDepartment(newDepartment);
            user.setUpdateTime(new Date());
            return userRepository.save(user);
        }
        return null;
    }
    
    public Double calculateTotalSalaryByDepartment(String department) {
        List<User> employees = userRepository.findByDepartment(department);
        return employees.stream()
                .filter(user -> user.getSalary() != null)
                .mapToDouble(User::getSalary)
                .sum();
    }
}