package com.example.refactor.service;

import com.example.refactor.entity.User;
import com.example.refactor.repository.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 通知服务 - 负责用户联系信息管理和通知发送
 */
@Service
public class NotificationService {
    
    @Autowired
    private UserRepository userRepository;
    
    public void updateContactInfo(Long userId, String phone, String address, String emergencyContact) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null) {
            user.setPhone(phone);
            user.setAddress(address);
            user.setEmergencyContact(emergencyContact);
            user.setUpdateTime(new Date());
            userRepository.save(user);
        }
    }
    
    public void sendEmailNotification(Long userId, String message) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null && user.getEmail() != null) {
            // 模拟发送邮件
            System.out.println("发送邮件到: " + user.getEmail() + ", 内容: " + message);
        }
    }
    
    public void sendSMSNotification(Long userId, String message) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null && user.getPhone() != null) {
            // 模拟发送短信
            System.out.println("发送短信到: " + user.getPhone() + ", 内容: " + message);
        }
    }
    
    public void notifyEmergencyContact(Long userId, String message) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null && user.getEmergencyContact() != null) {
            // 模拟通知紧急联系人
            System.out.println("通知紧急联系人: " + user.getEmergencyContact() + ", 内容: " + message);
        }
    }
    
    public void broadcastToAllUsers(String message) {
        List<User> activeUsers = userRepository.findByStatus("ACTIVE");
        for (User user : activeUsers) {
            if (user.getEmail() != null) {
                sendEmailNotification(user.getId(), message);
            }
        }
    }
    
    public void broadcastToDepartment(String department, String message) {
        List<User> departmentUsers = userRepository.findByDepartment(department);
        for (User user : departmentUsers) {
            if (user.getEmail() != null) {
                sendEmailNotification(user.getId(), message);
            }
        }
    }
}