package com.example.refactor.service;

import com.example.refactor.entity.User;
import com.example.refactor.entity.v2.UserProfile;
import com.example.refactor.repository.v2.UserProfileRepository;
import com.example.refactor.service.v2.UserFacadeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 通知服务V2 - 使用新架构的实现
 */
@Service
@Primary
@ConditionalOnProperty(name = "app.user.architecture", havingValue = "v2", matchIfMissing = false)
public class NotificationServiceV2 {
    
    @Autowired
    private UserFacadeService userFacadeService;
    
    @Autowired
    private UserProfileRepository userProfileRepository;
    
    public void updateContactInfo(Long userId, String phone, String address, String emergencyContact) {
        UserProfile profile = userProfileRepository.findById(userId).orElse(null);
        if (profile != null) {
            profile.setPhone(phone);
            profile.setAddress(address);
            profile.setEmergencyContact(emergencyContact);
            userProfileRepository.save(profile);
        }
    }
    
    public void sendEmailNotification(Long userId, String message) {
        User user = userFacadeService.getUserById(userId);
        if (user != null && user.getEmail() != null) {
            // 模拟发送邮件
            System.out.println("发送邮件到: " + user.getEmail() + ", 内容: " + message);
        }
    }
    
    public void sendSMSNotification(Long userId, String message) {
        User user = userFacadeService.getUserById(userId);
        if (user != null && user.getPhone() != null) {
            // 模拟发送短信
            System.out.println("发送短信到: " + user.getPhone() + ", 内容: " + message);
        }
    }
    
    public void notifyEmergencyContact(Long userId, String message) {
        User user = userFacadeService.getUserById(userId);
        if (user != null && user.getEmergencyContact() != null) {
            // 模拟通知紧急联系人
            System.out.println("通知紧急联系人: " + user.getEmergencyContact() + ", 内容: " + message);
        }
    }
    
    public void broadcastToAllUsers(String message) {
        List<User> activeUsers = userFacadeService.getActiveUsers();
        for (User user : activeUsers) {
            if (user.getEmail() != null) {
                sendEmailNotification(user.getId(), message);
            }
        }
    }
    
    public void broadcastToDepartment(String department, String message) {
        List<User> departmentUsers = userFacadeService.getEmployeesByDepartment(department);
        for (User user : departmentUsers) {
            if (user.getEmail() != null) {
                sendEmailNotification(user.getId(), message);
            }
        }
    }
    
    public void sendBulkNotification(List<String> emails, String message) {
        for (String email : emails) {
            User user = userFacadeService.getUserByEmail(email);
            if (user != null) {
                sendEmailNotification(user.getId(), message);
            }
        }
    }
}