package com.example.refactor.service;

import com.example.refactor.entity.User;
import com.example.refactor.repository.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 安全服务 - 负责用户登录、安全状态管理
 * 通过方法签名模式自动支持快照功能
 */
@Service
public class SecurityService {
    
    @Autowired
    private UserRepository userRepository;
    
    public boolean authenticateUser(String email, String password) {
        User user = userRepository.findByEmail(email);
        if (user != null && "ACTIVE".equals(user.getStatus())) {
            // 简化的认证逻辑
            updateLoginInfo(user.getId(), getClientIp());
            return true;
        }
        return false;
    }
    
    public void updateLoginInfo(Long userId, String clientIp) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null) {
            user.setLastLoginIp(clientIp);
            user.setLastLoginTime(new Date());
            user.setUpdateTime(new Date());
            userRepository.save(user);
        }
    }
    
    public void lockUser(Long userId) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null) {
            user.setStatus("LOCKED");
            user.setUpdateTime(new Date());
            userRepository.save(user);
        }
    }
    
    public void unlockUser(Long userId) {
        User user = userRepository.findById(userId).orElse(null);
        if (user != null) {
            user.setStatus("ACTIVE");
            user.setUpdateTime(new Date());
            userRepository.save(user);
        }
    }
    
    public List<User> getRecentlyLoggedInUsers() {
        // 获取最近24小时内登录的用户
        Date since = new Date(System.currentTimeMillis() - 24 * 60 * 60 * 1000);
        return userRepository.findByLastLoginTimeAfter(since);
    }
    
    public List<User> getLockedUsers() {
        return userRepository.findByStatus("LOCKED");
    }
    
    private String getClientIp() {
        // 模拟获取客户端IP
        return "192.168.1.100";
    }
}