package com.example.refactor.service;

import com.example.refactor.entity.User;
import com.example.refactor.repository.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 用户管理服务 - 负责基本的用户CRUD操作
 * 通过方法签名模式自动支持快照功能
 */
@Service
public class UserManagementService {
    
    @Autowired
    private UserRepository userRepository;
    
    public User createUser(String name, String email, String phone) {
        User user = new User(name, email);
        user.setPhone(phone);
        user.setCreateTime(new Date());
        user.setStatus("ACTIVE");
        return userRepository.save(user);
    }
    
    public User updateUser(Long id, String name, String email, String phone) {
        User user = userRepository.findById(id).orElse(null);
        if (user != null) {
            user.setName(name);
            user.setEmail(email);
            user.setPhone(phone);
            user.setUpdateTime(new Date());
            return userRepository.save(user);
        }
        return null;
    }
    
    public void deleteUser(Long id) {
        User user = userRepository.findById(id).orElse(null);
        if (user != null) {
            user.setStatus("DELETED");
            user.setUpdateTime(new Date());
            userRepository.save(user);
        }
    }
    
    public List<User> getAllActiveUsers() {
        return userRepository.findByStatus("ACTIVE");
    }
    
    public User getUserById(Long id) {
        return userRepository.findById(id).orElse(null);
    }
    
    public User getUserByEmail(String email) {
        return userRepository.findByEmail(email);
    }
}