package com.example.refactor.service;

import com.example.refactor.entity.User;
import com.example.refactor.service.v2.UserFacadeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户管理服务V2 - 使用新架构的实现
 * 通过配置开关控制是否启用新架构
 */
@Service
@Primary
@ConditionalOnProperty(name = "app.user.architecture", havingValue = "v2", matchIfMissing = false)
public class UserManagementServiceV2 {
    
    @Autowired
    private UserFacadeService userFacadeService;
    
    public User createUser(String name, String email, String phone) {
        return userFacadeService.createCompleteUser(name, email, phone, null, null, null);
    }
    
    public User updateUser(Long id, String name, String email, String phone) {
        return userFacadeService.updateUserProfile(id, name, email, phone);
    }
    
    public void deleteUser(Long id) {
        userFacadeService.deleteUser(id);
    }
    
    public List<User> getAllActiveUsers() {
        return userFacadeService.getActiveUsers();
    }
    
    public User getUserById(Long id) {
        return userFacadeService.getUserById(id);
    }
    
    public User getUserByEmail(String email) {
        return userFacadeService.getUserByEmail(email);
    }
}